[![PyPI](https://img.shields.io/pypi/v/hydra-core)](https://pypi.org/project/hydra-core/)
[![CircleCI](https://img.shields.io/circleci/build/github/facebookresearch/hydra?token=af199cd2deca9e70e53776f9ded96284b10687e9)](https://circleci.com/gh/facebookresearch/hydra)
![PyPI - License](https://img.shields.io/pypi/l/hydra-core)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hydra-core)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/hydra-core.svg)](https://pypistats.org/packages/hydra-core)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://hydra-framework.zulipchat.com)


# Hydra
A framework for elegantly configuring complex applications.

Check the [website](https://cli.dev/) for more information.

## License
Hydra is licensed under [MIT License](LICENSE).

